/*
 * Copyright (c) 2024.  Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes
 * Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten.postfach.muk;

import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.context.properties.ConfigurationPropertiesScan;
import org.springframework.context.annotation.Configuration;

import lombok.Getter;
import lombok.Setter;

@Getter
@Setter
@Configuration
@ConfigurationProperties(prefix = MukPostfachProperties.PREFIX)
@ConfigurationPropertiesScan
public class MukPostfachProperties {
	public static final String MAIL_BODY = """
	  Die Antwort des Kunden befindet sich im Anhang.

	  Bitte sehen Sie die Anhänge an.
	  """;
	public static final String PREFIX = "ozgcloud.muk";
	/**
	 * Adresse des ELSTER-Transfer Servers. Mandatory: Nein. Wenn nicht gesetzt, dann ist das mein Unternehmenkonto Postfach nicht verfügbar
	 */
	private String server;
	/**
	 * Antwortfrist in Tagen. Mandatory: Nein Default Wert: 30 Tage
	 */
	private Long replyInDays = 30L;
	/**
	 * Prefix des Betreffs von Antworten. Mandatory: Nein Default Wert: Antwort auf
	 */
	private String replySubjectPrefix = "Antwort auf ";
	/**
	 * Name des Absenders. Mandatory: Nein Default Wert: OZG-Cloud
	 */
	private String sender = "OZG-Cloud";
	/**
	 * Nachrichttext der gesendeten Antwort. Mandatory: Nein
	 */
	private String body = MAIL_BODY;

	/**
	 * Der Name des Elster-Transfer Users, der berechtigt ist die Postfachnachrichten der Instanz vom MUK-Postfach zu laden. Der Name muss in der
	 * user.yml Datei des Elster-Transfer Dienstes hinterlegt sein-
	 */
	private String userName = "--not-set--";

	/**
	 * Das Passwort des Elster-Transfer Users, der berechtigt ist die Postfachnachrichten der Instanz vom MUK-Postfach zu laden. Der bcrpyt2 Hash des
	 * Passworts muss in der user.yml Datei des Elster-Transfer Dienstes hinterlegt sein-
	 */
	private String password = "--not-set--";
}
