/*
 * Copyright (c) 2024.  Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes
 * Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten.postfach.muk;

import java.util.stream.Stream;

import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestClientException;

import de.ozgcloud.nachrichten.postfach.PostfachNachricht;
import de.ozgcloud.nachrichten.postfach.PostfachRemoteService;
import de.ozgcloud.nachrichten.postfach.muk.transfer.ElsterTransferRemoteService;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;

@Log4j2
@Service
@RequiredArgsConstructor
@ConditionalOnProperty(prefix = MukPostfachProperties.PREFIX, name = { "server" })
public class MukPostfachRemoteService implements PostfachRemoteService {
	public static final String POSTFACH_TYPE_MUK = "MUK";
	private final ElsterTransferRemoteService elsterTransferService;

	@Override
	public void sendMessage(PostfachNachricht postfachNachricht) {
		LOG.info("Sending PostfachNachricht with id {} and messageId {} to ElsterTransferService.", postfachNachricht.getId(),
		  postfachNachricht.getMessageId());
		try {
			var response = elsterTransferService.send(postfachNachricht);
			LOG.info("Submitted BereitstellungsAuftrag with id {}", response.getId());
		} catch (RestClientException e) {
			throw new MukServerException(e.getMessage(), e);
		}
	}

	@Override
	public Stream<PostfachNachricht> getAllMessages() {
		return elsterTransferService.getAllMessages();
	}

	@Override
	public void deleteMessage(String messageId) {
		LOG.debug("Mein Unternehmenskonto doesn't support this operation.");
	}

	@Override
	public String getPostfachType() {
		return POSTFACH_TYPE_MUK;
	}

	@Override
	public boolean isReplyAllowed() {
		return true;
	}
}
