/*
 * Copyright (c) 2024.  Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes
 * Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten.postfach.muk.transfer;

import static de.ozgcloud.nachrichten.postfach.muk.transfer.ElsterTransferRemoteService.*;

import java.io.IOException;
import java.nio.file.Files;
import java.nio.file.Path;

import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;
import org.springframework.web.client.RestClient;

import de.ozgcloud.muk.elster.transfer.AuftragAngelegt;
import de.ozgcloud.muk.elster.transfer.BereitstellungAuftragNeuV3;
import de.ozgcloud.muk.elster.transfer.UploadInfo;
import de.ozgcloud.nachrichten.postfach.muk.MukPostfachProperties;
import lombok.RequiredArgsConstructor;
import lombok.extern.log4j.Log4j2;

@Log4j2
@Service
@RequiredArgsConstructor
@ConditionalOnProperty(prefix = MukPostfachProperties.PREFIX, name = { "server" })
public class ElsterRestClient {
	private final RestClient restClient;
	private final MukPostfachProperties postfachProperties;

	UploadInfo postUpload(final Path tempFile) throws IOException {
		LOG.info("Uploading file {} to address {}", tempFile, postfachProperties.getServer() + BEREITSTELLUNG_UPLOAD_ENDPUNKT);
		return restClient.post()
		  .uri(postfachProperties.getServer() + BEREITSTELLUNG_UPLOAD_ENDPUNKT)
		  .body(Files.readAllBytes(tempFile))
		  .contentType(MediaType.APPLICATION_JSON)
		  .headers(httpHeaders -> httpHeaders.setBasicAuth(postfachProperties.getUserName(), postfachProperties.getPassword()))
		  .retrieve().body(UploadInfo.class);
	}

	AuftragAngelegt postBereitstellungsauftrag(BereitstellungAuftragNeuV3 bereitstellungAuftrag) {
		LOG.info("Sending Bereistellungsauftrag {} to address {}", bereitstellungAuftrag, postfachProperties.getServer() + BEREITSTELLUNGS_ENDPUNKT);
		return restClient.post()
		  .uri(postfachProperties.getServer() + BEREITSTELLUNGS_ENDPUNKT)
		  .body(bereitstellungAuftrag)
		  .contentType(MediaType.APPLICATION_JSON)
		  .headers(httpHeaders -> httpHeaders.setBasicAuth(postfachProperties.getUserName(), postfachProperties.getPassword()))
		  .retrieve().body(AuftragAngelegt.class);
	}

	<T> T getForObject(String url, Class<T> clazz) {
		LOG.info("Loading {} from address {}", clazz.getName(), url);
		return restClient
		  .get()
		  .uri(url)
		  .headers(httpHeaders -> httpHeaders.setBasicAuth(postfachProperties.getUserName(), postfachProperties.getPassword()))
		  .retrieve()
		  .body(clazz);
	}
}
