/*
 * Copyright (c) 2024.  Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes
 * Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten.postfach.muk.transfer;

import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.ReportingPolicy;

import de.ozgcloud.apilib.file.OzgCloudFile;
import de.ozgcloud.apilib.file.OzgCloudUploadFile;
import de.ozgcloud.muk.elster.transfer.AnhangMimeType;
import de.ozgcloud.muk.elster.transfer.BereitstellungAnhangWithUploadId;
import de.ozgcloud.muk.elster.transfer.DownloadAnhangDetails;

@Mapper(unmappedTargetPolicy = ReportingPolicy.WARN)
public interface MukOzgCloudFileMapper {

	@Mapping(target = "dateinameMitErweiterung", source = "name")
	@Mapping(target = "dateiBezeichnung", expression = "java(toDateiBezeichnung(ozgCloudFile))")
	@Mapping(target = "mimeType", expression = "java(toAnhangMimeType(ozgCloudFile))")
	@Mapping(target = "uploadId", ignore = true)
	BereitstellungAnhangWithUploadId toBereitstellungAnhangWithUploadId(OzgCloudFile ozgCloudFile);

	default String toDateiBezeichnung(OzgCloudFile ozgCloudFile) {
		return ozgCloudFile.getName().substring(0, ozgCloudFile.getName().lastIndexOf('.'));
	}

	default AnhangMimeType toAnhangMimeType(OzgCloudFile ozgCloudFile) {
		return AnhangMimeType.fromValue(ozgCloudFile.getContentType());
	}

	@Mapping(target = "name", source = "dateinameMitErweiterung")
	@Mapping(target = "contentType", expression = "java(toContentType(bereitstellungAnhang))")
	@Mapping(target = "id", ignore = true)
	@Mapping(target = "size", ignore = true)
	OzgCloudFile toOzgCloudFile(BereitstellungAnhangWithUploadId bereitstellungAnhang);

	@Mapping(target = "fileName", source = "datei")
	@Mapping(target = "contentType", source = "mimeType")
	@Mapping(target = "vorgangId", ignore = true)
	@Mapping(target = "fieldName", ignore = true)
	OzgCloudUploadFile toOzgCloudUploadFile(DownloadAnhangDetails downloadAnhangDetails);

	default String toContentType(BereitstellungAnhangWithUploadId bereitstellungAnhang) {
		return bereitstellungAnhang.getMimeType().getValue();
	}
}
