/*
 * Copyright (c) 2024.  Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes
 * Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten.postfach.muk.transfer;

import java.util.Objects;

import org.mapstruct.Mapper;
import org.mapstruct.Mapping;
import org.mapstruct.ReportingPolicy;

import de.ozgcloud.muk.elster.transfer.BereitstellungAuftragNeuV3;
import de.ozgcloud.nachrichten.postfach.PostfachAddressIdentifier;
import de.ozgcloud.nachrichten.postfach.PostfachNachricht;

@Mapper(unmappedTargetPolicy = ReportingPolicy.WARN)
public interface MukPostfachMessageMapper {
	String DATENART_BESCHEID = "EPBescheid";
	String DATENART_KURZMITTEILUNG = "EPKurzmitteilung";
	String DATENART_MITTEILUNG = "EPMitteilung";

	@Mapping(target = "accountId", source = "postfachAddress.identifier")
	@Mapping(target = "htmlAnschreiben", source = "mailBody")
	@Mapping(target = "betreff", source = "subject")
	@Mapping(target = "datenart", expression = "java(getDatenart(postfachNachricht))")
	@Mapping(target = "bescheidDatum", source = "sentAt", dateFormat = "yyyy-MM-dd")
	@Mapping(target = "empfaengerreferenz", source = "vorgangId")
	@Mapping(target = "geschaeftszeichen", source = "vorgangId")
	@Mapping(target = "absender", source = "createdBy")
	@Mapping(target = "emailAdresse", ignore = true)
	@Mapping(target = "anhaenge", ignore = true)
	BereitstellungAuftragNeuV3 toTransferMessage(PostfachNachricht postfachNachricht);

	default String map(PostfachAddressIdentifier postfachAddressIdentifier) {
		return postfachAddressIdentifier.toString();
	}

	default String getDatenart(PostfachNachricht postfachNachricht) {
		var hasAttachments = Objects.nonNull(postfachNachricht.getAttachments()) && !postfachNachricht.getAttachments().isEmpty();
		if (hasAttachments && postfachNachricht.getSubject().contains("Bescheid")) {
			return DATENART_BESCHEID;
		} else if (hasAttachments) {
			return DATENART_MITTEILUNG;
		} else {
			return DATENART_KURZMITTEILUNG;
		}
	}
}
