/*
 * Copyright (c) 2024.  Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes
 * Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten.postfach.muk.transfer;

import java.nio.ByteBuffer;
import java.util.UUID;

import org.bson.types.ObjectId;

import lombok.AccessLevel;
import lombok.NoArgsConstructor;

/**
 * Converts mongodb {@link ObjectId} to java {@link UUID} in both sides using version 4 (randomly generated) UUIDS. Based on MongoUUIDConverter.java
 * from Lukasz Frankowski (lifeinide.com)
 */
@NoArgsConstructor(access = AccessLevel.PRIVATE)
class ObjectIdToUUIDConverter {
	public static UUID toUUID(String objectIdString) {
		ObjectId objectId = new ObjectId(objectIdString);
		byte[] objectIdBytes = objectId.toByteArray();
		byte[] uuidBytes = new byte[16];

		System.arraycopy(objectIdBytes, 0, uuidBytes, 0, 6);
		System.arraycopy(objectIdBytes, 6, uuidBytes, 10, 6);

		uuidBytes[6] &= 0x0f;           /* clear version        */
		uuidBytes[6] |= 0x40;           /* set to version 4     */
		uuidBytes[8] &= 0x3f;           /* clear variant        */
		uuidBytes[8] |= (byte) 0x80;    /* set to IETF variant  */

		ByteBuffer buffer = ByteBuffer.wrap(uuidBytes);

		return new UUID(buffer.getLong(), buffer.getLong());
	}

	public static ObjectId toObjectId(UUID uuid) {
		byte[] uuidBytes = new byte[16];
		ByteBuffer.allocate(16).putLong(uuid.getMostSignificantBits()).putLong(uuid.getLeastSignificantBits()).position(0)
		  .get(uuidBytes);

		if (uuidBytes[6] != 64 || uuidBytes[7] != 0 || uuidBytes[8] != -128 || uuidBytes[9] != 0) {
			throw new IllegalArgumentException(String.format("UUID: %s has not been created from ObjectId", uuid));
		}

		byte[] objectIdBytes = new byte[12];

		System.arraycopy(uuidBytes, 0, objectIdBytes, 0, 6);
		System.arraycopy(uuidBytes, 10, objectIdBytes, 6, 6);

		return new ObjectId(objectIdBytes);
	}
}
