/*
 * Copyright (c) 2024.  Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes
 * Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten.postfach.muk;

import static de.ozgcloud.nachrichten.postfach.muk.transfer.MukPostfachMessageMapper.*;

import java.net.URI;
import java.time.LocalDate;
import java.util.List;
import java.util.UUID;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.muk.elster.transfer.AnhangMimeType;
import de.ozgcloud.muk.elster.transfer.BereitstellungAnhangWithUploadId;
import de.ozgcloud.muk.elster.transfer.BereitstellungAntwortlink;
import de.ozgcloud.muk.elster.transfer.BereitstellungAuftragNeuV3;

public class BereitstellungAuftragTestFactory {
	public static final LocalDate BESCHEID_DATUM = LocalDate.of(2019, 1, 1);
	public static final String EMPFAENGER_REFERENZ = UUID.randomUUID().toString();
	public static final String ABSENDER = LoremIpsum.getInstance().getName();
	public static final String BETREFF = LoremIpsum.getInstance().getWords(3);
	public static final String ACCOUNT_ID = UUID.randomUUID().toString();
	public static final String GESCHAEFTSZEICHEN = UUID.randomUUID().toString();
	public static final String ANSCHREIBEN = LoremIpsum.getInstance().getParagraphs(2, 4);
	public static final List<BereitstellungAnhangWithUploadId> ANHAENGE = createAnhangList();
	public static final String ANHANG_NAME = LoremIpsum.getInstance().getWords(1) + ".csv";
	public static final String ANHANG_BEZEICHNUNG = LoremIpsum.getInstance().getWords(5);
	public static final UUID ANHANG_UPLOAD_ID = UUID.randomUUID();
	public static final List<BereitstellungAntwortlink> ANTWORT_LINKS = createAntwortLinks();
	public static final String ANTWORT_LINK_BESCHREIBUNG = LoremIpsum.getInstance().getWords(5);
	public static final String ANTWORT_LINK_TITLE = LoremIpsum.getInstance().getWords(2);
	public static final URI ANTWORT_LINK_URI = URI.create(LoremIpsum.getInstance().getUrl());

	static List<BereitstellungAnhangWithUploadId> createAnhangList() {
		var anhang = new BereitstellungAnhangWithUploadId();
		anhang.setDateiBezeichnung(ANHANG_BEZEICHNUNG);
		anhang.setMimeType(AnhangMimeType.TEXT_CSV);
		anhang.setUploadId(ANHANG_UPLOAD_ID);
		anhang.setDateinameMitErweiterung(ANHANG_NAME);
		return List.of(anhang);
	}

	static List<BereitstellungAntwortlink> createAntwortLinks() {
		var link = new BereitstellungAntwortlink();
		link.setBeschreibung(ANTWORT_LINK_BESCHREIBUNG);
		link.setTitel(ANTWORT_LINK_TITLE);
		link.setUrl(ANTWORT_LINK_URI);
		return List.of(link);
	}

	public static BereitstellungAuftragNeuV3 createBescheid() {
		var auftrag = new BereitstellungAuftragNeuV3();
		auftrag.setBescheidDatum(BESCHEID_DATUM);
		auftrag.setEmpfaengerreferenz(EMPFAENGER_REFERENZ);
		auftrag.setDatenart(DATENART_BESCHEID);
		auftrag.setAbsender(ABSENDER);
		auftrag.setBetreff(BETREFF);
		auftrag.setAccountId(ACCOUNT_ID);
		auftrag.setGeschaeftszeichen(GESCHAEFTSZEICHEN);
		auftrag.setHtmlAnschreiben(ANSCHREIBEN);
		auftrag.setAnhaenge(ANHAENGE);
		auftrag.setAntwortlinks(ANTWORT_LINKS);
		return auftrag;
	}

	public static BereitstellungAuftragNeuV3 createMitteilung() {
		var auftrag = new BereitstellungAuftragNeuV3();
		auftrag.setEmpfaengerreferenz(EMPFAENGER_REFERENZ);
		auftrag.setDatenart(DATENART_KURZMITTEILUNG);
		auftrag.setAbsender(ABSENDER);
		auftrag.setBetreff(BETREFF);
		auftrag.setAccountId(ACCOUNT_ID);
		auftrag.setGeschaeftszeichen(GESCHAEFTSZEICHEN);
		auftrag.setHtmlAnschreiben(ANSCHREIBEN);
		auftrag.setAntwortlinks(ANTWORT_LINKS);
		return auftrag;
	}

	public static BereitstellungAuftragNeuV3 createAuftrag() {
		var auftrag = new BereitstellungAuftragNeuV3();
		auftrag.setEmpfaengerreferenz(EMPFAENGER_REFERENZ);
		auftrag.setAbsender(ABSENDER);
		auftrag.setBetreff(BETREFF);
		auftrag.setAccountId(ACCOUNT_ID);
		auftrag.setGeschaeftszeichen(GESCHAEFTSZEICHEN);
		auftrag.setHtmlAnschreiben(ANSCHREIBEN);
		auftrag.setAntwortlinks(ANTWORT_LINKS);
		return auftrag;
	}
}
