/*
 * Copyright (c) 2024.  Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes
 * Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten.postfach.muk;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.TestPropertySource;

import de.ozgcloud.common.test.ITCase;
import de.ozgcloud.nachrichten.postfach.muk.transfer.ElsterTransferRemoteService;

@SpringBootTest(
  classes = { MukPostfachProperties.class })
@ITCase
@TestPropertySource(properties = { "ozgcloud.muk.server=localhost", "ozgcloud.muk.user-name=user", "ozgcloud.muk.password=xxxx" })
public class MukPostfachPropertiesITCase {
	@Nested
	class TestMukPostfachProperties {
		@Autowired
		private MukPostfachProperties mukPostfachProperties;

		@Test
		void shouldHaveProperties() {
			assertThat(mukPostfachProperties).isNotNull();
		}

		@Test
		void shouldHaveMukServer() {
			assertThat(mukPostfachProperties.getServer()).isEqualTo("localhost");
		}

		@Test
		void shouldHaveMukUserName() {
			assertThat(mukPostfachProperties.getUserName()).isEqualTo("user");
		}

		@Test
		void shouldHavePasswordHash() {
			assertThat(mukPostfachProperties.getPassword()).isEqualTo("xxxx");
		}
	}

	@TestPropertySource(properties = { "ozgcloud.muk.user-name=user", "ozgcloud.muk.password=hash" })
	@Nested
	class TestMukPostfachNotConfigured {
		@Autowired(required = false)
		private MukPostfachRemoteService mukPostfachRemoteService;

		@Autowired(required = false)
		private ElsterTransferRemoteService elsterTransferRemoteService;

		@Test
		void shouldNotInitMukPostfachRemoteService() {
			assertThat(mukPostfachRemoteService).isNull();
		}

		@Test
		void shouldNotInitElsterTransferRemoteService() {
			assertThat(elsterTransferRemoteService).isNull();
		}
	}

	@TestPropertySource(properties = { "ozgcloud.muk.other=etwas" })
	@Nested
	class TestMukPostfachAndUserNotConfigured {
		@Autowired(required = false)
		private MukPostfachRemoteService mukPostfachRemoteService;

		@Autowired(required = false)
		private ElsterTransferRemoteService elsterTransferRemoteService;

		@Test
		void shouldNotInitMukPostfachRemoteService() {
			assertThat(mukPostfachRemoteService).isNull();
		}

		@Test
		void shouldNotInitElsterTransferRemoteService() {
			assertThat(elsterTransferRemoteService).isNull();
		}
	}
}
