/*
 * Copyright (c) 2024.  Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes
 * Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten.postfach.muk;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

import org.apache.commons.io.FileUtils;
import org.assertj.core.util.Files;
import org.springframework.boot.autoconfigure.condition.ConditionalOnMissingBean;
import org.springframework.stereotype.Service;

import de.ozgcloud.apilib.file.OzgCloudFile;
import de.ozgcloud.apilib.file.OzgCloudFileId;
import de.ozgcloud.apilib.file.OzgCloudFileService;
import de.ozgcloud.apilib.file.OzgCloudUploadFile;
import de.ozgcloud.common.errorhandling.TechnicalException;
import lombok.extern.log4j.Log4j2;

@Log4j2
@Service
@ConditionalOnMissingBean({ OzgCloudFileService.class })
public class MukTestOzgCloudFileService implements OzgCloudFileService {
	private static final byte[] TEST_DATA = "1,Hello World!".getBytes();
	private static final OzgCloudFile DUMMY_FILE;

	static {
		DUMMY_FILE = OzgCloudFile.builder()
		  .id(OzgCloudFileId.from("42"))
		  .contentType("text/csv")
		  .size(TEST_DATA.length)
		  .name("helloWorld.csv").build();
	}

	public OzgCloudFile getFile(OzgCloudFileId id) {
		return DUMMY_FILE;
	}

	public void writeFileDataToStream(OzgCloudFileId id, OutputStream streamToWriteData) {
		try {
			streamToWriteData.write(TEST_DATA);
		} catch (IOException e) {
			throw new TechnicalException("Error writing dummy data.", e);
		}
	}

	@Override
	public OzgCloudFileId uploadFile(OzgCloudUploadFile file, InputStream dataStream) {
		try {
			var tmpFile = Files.newTemporaryFile();
			FileUtils.writeByteArrayToFile(tmpFile, dataStream.readAllBytes());
			LOG.info("Wrote data to file {}", tmpFile);
		} catch (IOException e) {
			throw new TechnicalException("Error writing dummy data.", e);
		}
		return OzgCloudFileId.from(file.getVorgangId());
	}

}
