/*
 * Copyright (c) 2024.  Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes
 * Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten.postfach.muk.transfer;

import static de.ozgcloud.nachrichten.postfach.muk.PostfachNachrichtTestFactory.*;

import java.net.URI;
import java.util.List;
import java.util.UUID;

import org.bson.types.ObjectId;

import de.ozgcloud.muk.elster.transfer.AntwortDetails;
import de.ozgcloud.muk.elster.transfer.AntwortDetailsList;
import de.ozgcloud.muk.elster.transfer.DownloadAnhangDetails;

public class AntwortDetailsTestFactory {
	public static final String DATEI = "test-data.csv";
	public static final String VORGANG_OBJECT_ID = ObjectId.get().toHexString();
	public static final String DATEI_BEZEICHNUNG = "VorgangId[" + VORGANG_OBJECT_ID + "] Test";
	public static final URI DOWNLOAD_URI = URI.create("/download");
	public static final String TEXT_CSV = "text/csv";
	public static final UUID ZUORDNUNG = ObjectIdToUUIDConverter.toUUID(NACHRICHT_ID);

	static AntwortDetails create() {
		var antwortDetails = new AntwortDetails();
		antwortDetails.setAnhaenge(List.of(createDownloadAnhangDetails()));
		antwortDetails.setZuordnungskriterium(ZUORDNUNG);
		return antwortDetails;
	}

	static DownloadAnhangDetails createDownloadAnhangDetails() {
		var antwortDetails = new DownloadAnhangDetails();
		antwortDetails.setDatei(DATEI);
		antwortDetails.setDownloadUrl(DOWNLOAD_URI);
		antwortDetails.setDateiBezeichnung(DATEI_BEZEICHNUNG);
		antwortDetails.setMimeType(TEXT_CSV);
		return antwortDetails;
	}

	static AntwortDetailsList createAntwortDetailsList() {
		var antwortDetailsList = new AntwortDetailsList();
		antwortDetailsList.setDatensaetze(List.of(create()));
		return antwortDetailsList;
	}
}
