/*
 * Copyright (c) 2024.  Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes
 * Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten.postfach.muk.transfer;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.Mockito.*;

import java.io.BufferedInputStream;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;

import org.junit.jupiter.api.Test;
import org.mockito.InjectMocks;
import org.mockito.Mock;

import de.ozgcloud.apilib.file.OzgCloudFileId;
import de.ozgcloud.apilib.file.OzgCloudFileService;
import de.ozgcloud.apilib.file.OzgCloudFileTestFactory;
import de.ozgcloud.apilib.file.OzgCloudUploadFileTestFactory;

class AttachmentServerTest {
	@InjectMocks
	AttachmentService attachmentHandler;

	@Mock
	OzgCloudFileService ozgCloudFileService;

	@Test
	void shouldGetCloudFile() {
		when(ozgCloudFileService.getFile(any(OzgCloudFileId.class))).thenReturn(OzgCloudFileTestFactory.create());

		var file = attachmentHandler.getCloudFile(OzgCloudFileTestFactory.ID.toString());

		assertThat(file).isNotNull();
	}

	@Test
	void shouldGetFileContent() {
		ByteArrayOutputStream outputStream = new ByteArrayOutputStream();
		attachmentHandler.getFileContent(OzgCloudFileTestFactory.ID, outputStream);

		verify(ozgCloudFileService).writeFileDataToStream(any(OzgCloudFileId.class), any(ByteArrayOutputStream.class));
	}

	@Test
	void shouldStoreFileContent() throws IOException {
		when(ozgCloudFileService.uploadFile(any(), any())).thenReturn(OzgCloudFileTestFactory.ID);

		try (var dataStream = new BufferedInputStream(new ByteArrayInputStream("data".getBytes()))) {
			attachmentHandler.store(OzgCloudUploadFileTestFactory.create(), dataStream);
		}

		verify(ozgCloudFileService).uploadFile(any(), any());
	}
}