/*
 * Copyright (c) 2024.  Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes
 * Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten.postfach.muk.transfer;

import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;

import de.ozgcloud.apilib.file.OzgCloudFileTestFactory;
import de.ozgcloud.muk.elster.transfer.AnhangMimeType;
import de.ozgcloud.nachrichten.postfach.muk.BereitstellungAnhangTestFactory;

class MukOzgCloudFileMapperTest {

	MukOzgCloudFileMapper cloudFileMapper = Mappers.getMapper(MukOzgCloudFileMapper.class);

	@Nested
	class TestMappingBereitstellungAnhangWithUploadId {
		@Test
		void shouldMapDateinameMitErweiterung() {
			var file = cloudFileMapper.toOzgCloudFile(BereitstellungAnhangTestFactory.createWithUploadId());

			assertThat(file.getName()).isEqualTo(BereitstellungAnhangTestFactory.DATEINAME_MIT_ERWEITERUNG);
		}

		@Test
		void shouldMapType() {
			var file = cloudFileMapper.toOzgCloudFile(BereitstellungAnhangTestFactory.createWithUploadId());

			assertThat(file.getContentType()).isEqualTo(BereitstellungAnhangTestFactory.ANHANG_MIME_TYPE_CSV.getValue());
		}
	}

	@Nested
	class TestMappingOzgCloudFile {
		@Test
		void shouldMapDateiName() {
			var anhang = cloudFileMapper.toBereitstellungAnhangWithUploadId(OzgCloudFileTestFactory.create());

			assertThat(anhang.getDateiBezeichnung()).isEqualTo(
			  OzgCloudFileTestFactory.NAME.substring(0, OzgCloudFileTestFactory.NAME.lastIndexOf('.')));
		}

		@Test
		void shouldMapDateinameMitErweiterung() {
			var anhang = cloudFileMapper.toBereitstellungAnhangWithUploadId(OzgCloudFileTestFactory.create());

			assertThat(anhang.getDateinameMitErweiterung()).isEqualTo(OzgCloudFileTestFactory.NAME);
		}

		@Test
		void shouldMapType() {
			var anhang = cloudFileMapper.toBereitstellungAnhangWithUploadId(OzgCloudFileTestFactory.create());

			assertThat(anhang.getMimeType()).isEqualTo(AnhangMimeType.APPLICATION_PDF);
		}
	}

}