/*
 * Copyright (c) 2024.  Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes
 * Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten.postfach.muk.transfer;

import static de.ozgcloud.nachrichten.postfach.muk.PostfachNachrichtTestFactory.*;
import static de.ozgcloud.nachrichten.postfach.muk.transfer.MukPostfachMessageMapper.*;
import static org.assertj.core.api.Assertions.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;

import de.ozgcloud.muk.elster.transfer.BereitstellungAuftragNeuV3;
import de.ozgcloud.nachrichten.postfach.muk.PostfachNachrichtTestFactory;

class MukPostfachMessageMapperTest {
	MukPostfachMessageMapper mapper = Mappers.getMapper(MukPostfachMessageMapper.class);

	@Nested
	class TestMapToBereitstellungAuftragNeuV3 {

		@Test
		void shouldMapSubjectToBetreff() {
			var result = map();

			assertThat(result.getBetreff()).isEqualTo(PostfachNachrichtTestFactory.SUBJECT);
		}

		@Test
		void shouldMapSentAtToBescheidDatum() {
			var result = map();

			assertThat(result.getBescheidDatum()).isEqualTo(PostfachNachrichtTestFactory.SENT_AT.toLocalDate());
		}

		@Test
		void shouldMapMailBodyToHtmlAnschreiben() {
			var result = map();

			assertThat(result.getHtmlAnschreiben()).isEqualTo(PostfachNachrichtTestFactory.MAIL_BODY);
		}

		@Test
		void shouldMapVorgangIdToEmpfaengerreferenz() {
			var result = map();

			assertThat(result.getEmpfaengerreferenz()).isEqualTo(NACHRICHT_ID);
		}

		@Test
		void shouldMapVorgangIdToGeschaeftszeichen() {
			var result = map();

			assertThat(result.getEmpfaengerreferenz()).isEqualTo(NACHRICHT_ID);
		}

		@Test
		void shouldMapPostfachIdentifierToAccountId() {
			var result = map();

			assertThat(result.getAccountId()).isEqualTo(POSTFACH_ID);
		}

		@Test
		void shouldMapCreatedByToAbsender() {
			var result = map();

			assertThat(result.getAbsender()).isEqualTo(PostfachNachrichtTestFactory.CREATED_BY);
		}

		private BereitstellungAuftragNeuV3 map() {
			return mapper.toTransferMessage(PostfachNachrichtTestFactory.create());
		}
	}

	@Nested
	class TestSettingDatenart {
		@Test
		void shouldSetDatenartMitteilung() {
			var nachricht = PostfachNachrichtTestFactory.create();

			assertThat(mapper.toTransferMessage(nachricht).getDatenart()).isEqualTo(DATENART_MITTEILUNG);
		}

		@Test
		void shouldSetDatenartKurzmitteilung() {
			var nachricht = PostfachNachrichtTestFactory.createBuilder().attachments(null).build();

			assertThat(mapper.toTransferMessage(nachricht).getDatenart()).isEqualTo(DATENART_KURZMITTEILUNG);
		}

		@Test
		void shouldSetDatenartBescheid() {
			var nachricht = PostfachNachrichtTestFactory.createBuilder().subject("Etwas mit Bescheid").build();

			assertThat(mapper.toTransferMessage(nachricht).getDatenart()).isEqualTo(DATENART_BESCHEID);
		}
	}
}