/*
 * Copyright (c) 2024.  Das Land Schleswig-Holstein vertreten durch den Ministerpräsidenten des Landes
 * Schleswig-Holstein Staatskanzlei Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.nachrichten.postfach.muk.transfer;

import static org.assertj.core.api.Assertions.*;

import java.util.UUID;

import org.bson.types.ObjectId;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;

class ObjectIdToUUIDConverterTest {
	@Nested
	class TestConvertingToUUID {
		@Test
		void shouldConvertObjectIdToUUID() {
			var objectIdString = new ObjectId().toHexString();

			var uuid = ObjectIdToUUIDConverter.toUUID(objectIdString);
			assertThat(uuid).isNotNull();
		}
	}

	@Nested
	class TestConvertingToObjectIdString {
		UUID uuid;

		@BeforeEach
		void setUp() {
			uuid = ObjectIdToUUIDConverter.toUUID(new ObjectId().toHexString());
		}

		@Test
		void shouldConvertUUIDToObjectIdString() {
			var objectIdString = ObjectIdToUUIDConverter.toObjectId(uuid);

			assertThat(objectIdString).isNotNull();
		}

		@Test
		void shouldMatchObjectIdPattern() {
			var objectIdString = ObjectIdToUUIDConverter.toObjectId(uuid).toHexString();

			assertThat(ObjectId.isValid(objectIdString)).isTrue();
		}

		@Test
		void shouldNotConvertBecauseUUIDWasNotCreatedFromObjectId() {
			var uuid = UUID.randomUUID();

			assertThatExceptionOfType(IllegalArgumentException.class).isThrownBy(() -> ObjectIdToUUIDConverter.toObjectId(uuid));
		}
	}

	@Nested
	class TestConvertingToObjectIdAndBack {
		String objectIdString = new ObjectId().toHexString();
		UUID uuid = ObjectIdToUUIDConverter.toUUID(objectIdString);

		@Test
		void resultShouldMatchInput() {
			var convertedObjectIdString = ObjectIdToUUIDConverter.toObjectId(uuid).toHexString();

			assertThat(convertedObjectIdString).isEqualTo(objectIdString);
		}
	}
}